.. _support:

Support
=======
If you have a questions or issues about Eve, there are several options:

Send a Tweet
------------
If your question is less than 140 characters, feel free to send a tweet to
`@nicolaiarocci <http://twitter.com/nicolaiarocci>`_.

File an Issue
-------------
If you notice some unexpected behavior in Eve, or want to see support for a new
feature, `file an issue on GitHub
<https://github.com/nicolaiarocci/eve/issues>`_.

E-mail
------
I'm more than happy to answer any personal or in-depth questions about Eve.
Feel free to email `eve@nicolaiarocci.com <mailto:eve@nicolaiarocci.com>`_.

IRC
---
The official Freenode channel for Eve is `#evehq
<irc://irc.freenode.net/evehq>`_

